@@ -28,15 +28,20 @@ except ImportError:
 
 class HanLPClient(object):
 
-    def __init__(self, url: str, auth: str = None, timeout=5) -> None:
+    def __init__(self, url: str, auth: str = None, language=None, timeout=5) -> None:
         """
 
         Args:
             url (str): An API endpoint to a service provider.
             auth (str): An auth key licenced from a service provider.
+            language (str): The default language for each :func:`~hanlp_restful.HanLPClient.parse` call.
+                Contact the service provider for the list of languages supported.
+                Conventionally, ``zh`` is used for Chinese and ``mul`` for multilingual.
+                Leave ``None`` to use the default language on server.
             timeout (int): Maximum waiting time in seconds for a request.
         """
         super().__init__()
+        self._language = language
         self._timeout = timeout
         self._url = url
         if auth is None:
@@ -61,7 +66,20 @@ class HanLPClient(object):
             skip_tasks: The tasks to skip.
             language: The language of input text or tokens. ``None`` to use the default language on server.
 
-        Returns: A :class:`~hanlp_common.document.Document`.
+        Returns:
+            A :class:`~hanlp_common.document.Document`.
+
+        Raises:
+            HTTPError: Any errors happening on the Internet side or the server side. Refer to the ``code`` and ``msg``
+                of the exception for more details. A list of common errors :
+
+        - ``400 Bad Request`` indicates that the server cannot process the request due to a client
+          fault (e.g., text too long, language unsupported).
+        - ``401 Unauthorized`` indicates that the request lacks **valid** ``auth`` credentials for the API.
+        - ``422 Unprocessable Entity`` indicates that the content type of the request entity is not in
+          proper json format.
+        - ``429 Too Many Requests`` indicates the user has sent too many requests in a given
+          amount of time ("rate limiting").
 
         """
         assert text or tokens, 'At least one of text or tokens has to be specified.'
@@ -70,7 +88,7 @@ class HanLPClient(object):
             'tokens': tokens,
             'tasks': tasks,
             'skip_tasks': skip_tasks,
-            'language': language
+            'language': language or self._language
         })
         return Document(response)
 
@@ -82,7 +100,7 @@ class HanLPClient(object):
                  language: str = None,
                  ) -> Document:
         """
-        Parse a piece of text. This is a shortcut for :func:`~hanlp_restful.HanLPClient.parse`.
+        Parse a piece of text.
 
         Args:
             text: A paragraph (str), or a list of sentences (List[str]).
@@ -91,7 +109,20 @@ class HanLPClient(object):
             skip_tasks: The tasks to skip.
             language: The language of input text or tokens. ``None`` to use the default language on server.
 
-        Returns: A :class:`~hanlp_common.document.Document`.
+        Returns:
+            A :class:`~hanlp_common.document.Document`.
+
+        Raises:
+            HTTPError: Any errors happening on the Internet side or the server side. Refer to the ``code`` and ``msg``
+                of the exception for more details. A list of common errors :
+
+        - ``400 Bad Request`` indicates that the server cannot process the request due to a client
+          fault (e.g., text too long, language unsupported).
+        - ``401 Unauthorized`` indicates that the request lacks **valid** ``auth`` credentials for the API.
+        - ``422 Unprocessable Entity`` indicates that the content type of the request entity is not in
+          proper json format.
+        - ``429 Too Many Requests`` indicates the user has sent too many requests in a given
+          amount of time ("rate limiting").
 
         """
         return self.parse(text, tokens, tasks, skip_tasks)
@@ -99,7 +130,8 @@ class HanLPClient(object):
     def about(self) -> Dict[str, Any]:
         """Get the information about server and your client.
 
-        Returns: A dict containing your rate limit and server version etc.
+        Returns:
+            A dict containing your rate limit and server version etc.
 
         """
         info = self._send_get_json(self._url + '/about', {})
@@ -114,7 +146,10 @@ class HanLPClient(object):
         return urlopen(request, timeout=self._timeout).read().decode()
 
     def _send_post_json(self, url, form: Dict[str, Any]):
-        return json.loads(_post(url, form, {'Authorization': f'Basic {self._auth}'}, self._timeout))
+        headers = dict()
+        if self._auth:
+            headers['Authorization'] = f'Basic {self._auth}'
+        return json.loads(_post(url, form, headers, self._timeout))
 
     def _send_get(self, url, form: Dict[str, Any]):
         request = Request(url + '?' + urlencode(form))
